@@ -52,8 +52,8 @@ class LocalTest(unittest.TestCase):
         
         import hashlib
         
-        public = hashlib.md5('testBySettings-1').hexdigest()
-        secret = hashlib.md5('testBySettings-1').hexdigest()
+        public = hashlib.md5(b'testBySettings-1').hexdigest()
+        secret = hashlib.md5(b'testBySettings-1').hexdigest()
 
         dsn = 'threaded+https://%s:%s@localhost/1' % (public, secret)
         
